<?php

if (!defined('ABSPATH'))
    exit;

class CBB_Core
{

    /**
     * The single instance
     * @var    object
     * @access  private
     * @since    1.0.0
     */
    private static $_instance = null;

    /**
     * Settings class object
     * @var     object
     * @access  public
     * @since   1.0.0
     */
    public $settings = null;

    /**
     * The version number.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $_version;

    /**
     * The token.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $_token;

    /**
     * The main plugin file.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $file;

    /**
     * The main plugin directory.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $dir;

    /**
     * The plugin assets directory.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $assets_dir;

    /**
     * The plugin assets URL.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $assets_url;

    /**
     * Suffix for Javascripts.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $templates_url;

    /**
     * Suffix for Javascripts.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $script_suffix;

    /**
     * For menu instance
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $menu;

    /**
     * For template
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $plugin_slug;


    /*
     * Must load or not the js files ?
     */
    private $add_script;

    /**
     * Constructor function.
     * @access  public
     * @since   1.0.0
     * @return  void
     */
    public function __construct($file = '', $version = '1.0')
    {
        $this->_version = $version;
        $this->_token = 'cbb';
        $this->plugin_slug = 'cbb';

        $this->file = $file;
        $this->dir = dirname($this->file);
        $this->assets_dir = trailingslashit($this->dir) . 'assets';
        $this->assets_url = esc_url(trailingslashit(plugins_url('/assets/', $this->file)));

        add_action('wp_enqueue_scripts', array($this, 'frontend_enqueue_scripts'), 10,1);
        add_action('wp_enqueue_scripts', array($this, 'frontend_enqueue_styles'), 10, 1);
        add_action('plugins_loaded', array($this, 'init_localization')); 
        add_shortcode( 'creative_banner', array($this,'cbb_shortcode') );
    }
    
    

    /*
     * Plugin init localization
     */
    public function init_localization()
    {
        $moFiles = scandir(trailingslashit($this->dir) . 'languages/');
        foreach ($moFiles as $moFile) {
            if (strlen($moFile) > 3 && substr($moFile, -3) == '.mo' && strpos($moFile, get_locale()) > -1) {
                load_textdomain('cbb', trailingslashit($this->dir) . 'languages/' . $moFile);
            }
        }
    }
    
    public function cbb_shortcode($attributes, $content=null){
         global $wpdb;
         $banner = false;
        $table_name = $wpdb->prefix . "cbb_banners";
        $response = '';
        extract(shortcode_atts( array(
		'banner_id' => 1
	), $attributes));
        if($banner_id > 0){
            $response = '<div class="creative_banner" data-id="'.$banner_id.'"></div>';            
        }        
        
	return $response;
    }

    public function frontend_enqueue_scripts($hook = '')
    {
         global $wpdb;
         
        wp_register_script($this->_token . '-easejs', esc_url($this->assets_url) . 'js/easeljs-0.8.0.min.js', array('jquery'), $this->_version);
        wp_enqueue_script($this->_token . '-easejs');
        wp_register_script($this->_token . '-cbb-frontend', esc_url($this->assets_url) . 'js/cbb_frontend.min.js', array('jquery','jquery-ui-core'), $this->_version);
        wp_enqueue_script($this->_token . '-cbb-frontend');
        
        $bannersJS = array();
        $table_name = $wpdb->prefix . "cbb_banners";
        $banners = $wpdb->get_results("SELECT * FROM $table_name");
        foreach ($banners as $banner) {
            $banner->content = stripslashes($banner->content);
            $bannersJS[] = $banner;
        }

        $js_data[] = array(
            'assetsUrl' => esc_url($this->assets_url),
            'websiteUrl' => esc_url(get_home_url()),
            'banners'=>$bannersJS
        );
        wp_localize_script($this->_token . '-cbb-frontend', 'cbb_data', $js_data);
    }

    public function frontend_enqueue_styles($hook = '')
    {
        wp_register_style($this->_token . '-cbb-frontend', esc_url($this->assets_url) . 'css/cbb_frontend.css', array(), $this->_version);
        wp_enqueue_style($this->_token . '-cbb-frontend');
    }




    /**
     * Main CBB_Core Instance
     *
     *
     * @since 1.0.0
     * @static
     * @see CBB_Core()
     * @return Main CBB_Core instance
     */
    public static function instance($file = '', $version = '1.0.0')
    {
        if (is_null(self::$_instance)) {
            self::$_instance = new self($file, $version);
        }
        return self::$_instance;
    }

// End instance()

    /**
     * Cloning is forbidden.
     *
     * @since 1.0.0
     */
    public function __clone()
    {
    }

// End __clone()

    /**
     * Unserializing instances of this class is forbidden.
     *
     * @since 1.0.0
     */
    public function __wakeup()
    {
    }

// End __wakeup()

    /**
     * Return settings.
     * @access  public
     * @since   1.0.0
     * @return  void
     */
    public function getSettings()
    {
        global $wpdb;
        $table_name = $wpdb->prefix . "wpefc_settings";
        $settings = $wpdb->get_results("SELECT * FROM $table_name WHERE id=1 LIMIT 1");
        return $settings[0];
    }
    // End getSettings()


    /**
     * Log the plugin version number.
     * @access  public
     * @since   1.0.0
     * @return  void
     */
    private function _log_version_number()
    {
        update_option($this->_token . '_version', $this->_version);
    }

}
